@@ -54,8 +54,7 @@ func ConfigureLoginCommand(app *kingpin.Application, a *AwsVault) {
 		Short('s').
 		BoolVar(&input.UseStdout)
 
-	cmd.Arg("profile", "Name of the profile").
-		Required().
+	cmd.Arg("profile", "Name of the profile. If none given, credentials will be sourced from env vars").
 		HintAction(a.MustGetProfileNames).
 		StringVar(&input.ProfileName)
 
@@ -94,20 +93,29 @@ func LoginCommand(input LoginCommandInput, f *vault.ConfigFile, keyring keyring.
 
 	var credsProvider aws.CredentialsProvider
 
-	ckr := &vault.CredentialKeyring{Keyring: keyring}
-	// If AssumeRole or sso.GetRoleCredentials isn't used, GetFederationToken has to be used for IAM credentials
-	if config.HasRole() || config.HasSSOStartURL() {
-		credsProvider, err = vault.NewTempCredentialsProvider(config, ckr)
+	if input.ProfileName == "" {
+		// When no profile is specified, source credentials from the environment
+		credsProvider = vault.NewEnvironmentCredentialsProvider()
 	} else {
-		credsProvider, err = vault.NewFederationTokenCredentialsProvider(input.ProfileName, ckr, config)
-	}
-	if err != nil {
-		return fmt.Errorf("profile %s: %w", input.ProfileName, err)
+		// Use a profile from the AWS config file
+		ckr := &vault.CredentialKeyring{Keyring: keyring}
+		if config.HasRole() || config.HasSSOStartURL() {
+			// If AssumeRole or sso.GetRoleCredentials isn't used, GetFederationToken has to be used for IAM credentials
+			credsProvider, err = vault.NewTempCredentialsProvider(config, ckr)
+		} else {
+			credsProvider, err = vault.NewFederationTokenCredentialsProvider(input.ProfileName, ckr, config)
+		}
+		if err != nil {
+			return fmt.Errorf("profile %s: %w", input.ProfileName, err)
+		}
 	}
 
 	creds, err := credsProvider.Retrieve(context.TODO())
 	if err != nil {
-		return fmt.Errorf("Failed to get credentials for %s: %w", config.ProfileName, err)
+		return fmt.Errorf("Failed to get credentials: %w", err)
+	}
+	if creds.AccessKeyID == "" && input.ProfileName == "" {
+		return fmt.Errorf("argument 'profile' not provided, nor any AWS env vars found. Try --help")
 	}
 
 	jsonBytes, err := json.Marshal(map[string]string{
@@ -121,7 +129,7 @@ func LoginCommand(input LoginCommandInput, f *vault.ConfigFile, keyring keyring.
 
 	loginURLPrefix, destination := generateLoginURL(config.Region, input.Path)
 
-	req, err := http.NewRequest("GET", loginURLPrefix, nil)
+	req, err := http.NewRequestWithContext(context.TODO(), "GET", loginURLPrefix, nil)
 	if err != nil {
 		return err
 	}
@@ -153,7 +161,7 @@ func LoginCommand(input LoginCommandInput, f *vault.ConfigFile, keyring keyring.
 
 	var respParsed map[string]string
 
-	err = json.Unmarshal([]byte(body), &respParsed)
+	err = json.Unmarshal(body, &respParsed)
 	if err != nil {
 		return err
 	}
